..  -*- coding: utf-8 -*-

********
Tutorial
********

.. toctree::
   :maxdepth: 2

   tutorial

**What Next**


Now that you have an idea of what the NetworkX package provides,
you should investigate the parts of the package most useful for
you.  

:doc:`Reference Section</reference/index>` provides details on NetworkX.

:doc:`/examples/index` provides some example programs written using NetworkX.
